@@ -29,23 +29,6 @@ describe("ALB Rule Priority Generator", () => {
     console.log = origLog;
   });
 
-  test("Empty event payload fails", () => {
-    const request = nock(ResponseURL)
-      .put("/", (body) => {
-        return (
-          body.Status === "FAILED" &&
-          body.Reason ===
-            "Unsupported request type undefined (Log: /aws/lambda/testLambda/2021/06/28/[$LATEST]9b93a7dca7344adeb193d15c092dbbfd)"
-        );
-      })
-      .reply(200);
-    return LambdaTester(albRulePriorityHandler.nextAvailableRulePriorityHandler)
-      .event({})
-      .expectResolve(() => {
-        expect(request.isDone()).toBe(true);
-      });
-  });
-
   test("Bogus operation fails", () => {
     const bogusType = "bogus";
     const request = nock(ResponseURL)
@@ -60,6 +43,9 @@ describe("ALB Rule Priority Generator", () => {
     return LambdaTester(albRulePriorityHandler.nextAvailableRulePriorityHandler)
       .event({
         RequestType: bogusType,
+        RequestId: testRequestId,
+        ResourceProperties: {},
+        LogicalResourceId: "mockID",
       })
       .expectResolve(() => {
         expect(request.isDone()).toBe(true);
@@ -82,34 +68,9 @@ describe("ALB Rule Priority Generator", () => {
     return LambdaTester(albRulePriorityHandler.nextAvailableRulePriorityHandler)
       .event({
         RequestType: requestType,
-      })
-      .expectResolve(() => {
-        sinon.assert.notCalled(describeRulesFake);
-        expect(request.isDone()).toBe(true);
-      });
-  });
-
-  test("Update event is a no-op", () => {
-    const describeRulesFake = sinon.fake.resolves({
-      Rules: [],
-    });
-
-    AWS.mock("ELBv2", "describeRules", describeRulesFake);
-
-    const requestType = "Update";
-    const request = nock(ResponseURL)
-      .put("/", (body) => {
-        return (
-          body.Status === "SUCCESS" &&
-          body.PhysicalResourceId === "mockPhysicalID"
-        );
-      })
-      .reply(200);
-    return LambdaTester(albRulePriorityHandler.nextAvailableRulePriorityHandler)
-      .event({
-        RequestType: requestType,
+        RequestId: testRequestId,
+        ResourceProperties: {},
         LogicalResourceId: "mockID",
-        PhysicalResourceId: "mockPhysicalID",
       })
       .expectResolve(() => {
         sinon.assert.notCalled(describeRulesFake);
@@ -117,7 +78,7 @@ describe("ALB Rule Priority Generator", () => {
       });
   });
 
-  test("Create operation returns rule priority 1 when only the default rule is present", () => {
+  test("Create operation returns non-root rule priority 1 when only the default rule is present", () => {
     const describeRulesFake = sinon.fake.resolves({
       Rules: [
         {
@@ -154,6 +115,7 @@ describe("ALB Rule Priority Generator", () => {
         RequestId: testRequestId,
         ResourceProperties: {
           ListenerArn: testALBListenerArn,
+          RulePath: "/api",
         },
         LogicalResourceId: "mockID",
       })
@@ -168,7 +130,59 @@ describe("ALB Rule Priority Generator", () => {
       });
   });
 
-  test("Create operation returns rule priority 1 when the MAX rule is present", () => {
+  test("Update operation returns root rule priority 50000 when only the default rule is present", () => {
+    const describeRulesFake = sinon.fake.resolves({
+      Rules: [
+        {
+          Priority: "default",
+          Conditions: [],
+          RuleArn:
+            "arn:aws:elasticloadbalancing:us-west-2:000000000:listener-rule/app/rule",
+          IsDefault: true,
+          Actions: [
+            {
+              TargetGroupArn:
+                "arn:aws:elasticloadbalancing:us-west-2:000000000:targetgroup/tg",
+              Type: "forward",
+            },
+          ],
+        },
+      ],
+    });
+
+    AWS.mock("ELBv2", "describeRules", describeRulesFake);
+    const request = nock(ResponseURL)
+      .put("/", (body) => {
+        return (
+          body.Status === "SUCCESS" &&
+          body.Data.Priority == 50000 &&
+          body.PhysicalResourceId === "alb-rule-priority-mockID"
+        );
+      })
+      .reply(200);
+
+    return LambdaTester(albRulePriorityHandler.nextAvailableRulePriorityHandler)
+      .event({
+        RequestType: "Update",
+        RequestId: testRequestId,
+        ResourceProperties: {
+          ListenerArn: testALBListenerArn,
+          RulePath: "/",
+        },
+        LogicalResourceId: "mockID",
+      })
+      .expectResolve(() => {
+        sinon.assert.calledWith(
+          describeRulesFake,
+          sinon.match({
+            ListenerArn: testALBListenerArn,
+          })
+        );
+        expect(request.isDone()).toBe(true);
+      });
+  });
+
+  test("Create operation returns non-root rule priority 1 when any root rule is present", () => {
     const describeRulesFake = sinon.fake.resolves({
       Rules: [
         {
@@ -201,6 +215,7 @@ describe("ALB Rule Priority Generator", () => {
         RequestId: testRequestId,
         ResourceProperties: {
           ListenerArn: testALBListenerArn,
+          RulePath: "/api",
         },
       })
       .expectResolve(() => {
@@ -214,7 +229,7 @@ describe("ALB Rule Priority Generator", () => {
       });
   });
 
-  test("Create operation returns rule priority max + 1", () => {
+  test("Create operation returns non-root rule priority max + 1", () => {
     // This set of rules has the default, 3 and 5 rule priorities. We don't try to fill
     // in the gaps, we just create one that is 1 + the max. In this case, 6.
     const describeRulesFake = sinon.fake.resolves({
@@ -277,6 +292,7 @@ describe("ALB Rule Priority Generator", () => {
         RequestId: testRequestId,
         ResourceProperties: {
           ListenerArn: testALBListenerArn,
+          RulePath: "/api",
         },
       })
       .expectResolve(() => {
@@ -290,7 +306,82 @@ describe("ALB Rule Priority Generator", () => {
       });
   });
 
-  test("Create operation returns rule priority max + 1 for paginated response", () => {
+  test("Create operation returns root rule priority min - 1", () => {
+    const describeRulesFake = sinon.fake.resolves({
+      Rules: [
+        {
+          Priority: "default",
+          Conditions: [],
+          RuleArn:
+            "arn:aws:elasticloadbalancing:us-west-2:000000000:listener-rule/app/rule",
+          IsDefault: true,
+          Actions: [
+            {
+              TargetGroupArn:
+                "arn:aws:elasticloadbalancing:us-west-2:000000000:targetgroup/tg",
+              Type: "forward",
+            },
+          ],
+        },
+        {
+          Priority: "49999",
+          Conditions: [],
+          RuleArn:
+            "arn:aws:elasticloadbalancing:us-west-2:000000000:listener-rule/app/rule",
+          IsDefault: true,
+          Actions: [
+            {
+              TargetGroupArn:
+                "arn:aws:elasticloadbalancing:us-west-2:000000000:targetgroup/tg",
+              Type: "forward",
+            },
+          ],
+        },
+        {
+          Priority: "50000",
+          Conditions: [],
+          RuleArn:
+            "arn:aws:elasticloadbalancing:us-west-2:000000000:listener-rule/app/rule",
+          IsDefault: true,
+          Actions: [
+            {
+              TargetGroupArn:
+                "arn:aws:elasticloadbalancing:us-west-2:000000000:targetgroup/tg",
+              Type: "forward",
+            },
+          ],
+        },
+      ],
+    });
+
+    AWS.mock("ELBv2", "describeRules", describeRulesFake);
+    const request = nock(ResponseURL)
+      .put("/", (body) => {
+        return body.Status === "SUCCESS" && body.Data.Priority == 49998;
+      })
+      .reply(200);
+
+    return LambdaTester(albRulePriorityHandler.nextAvailableRulePriorityHandler)
+      .event({
+        RequestType: "Create",
+        RequestId: testRequestId,
+        ResourceProperties: {
+          ListenerArn: testALBListenerArn,
+          RulePath: "/",
+        },
+      })
+      .expectResolve(() => {
+        sinon.assert.calledWith(
+          describeRulesFake,
+          sinon.match({
+            ListenerArn: testALBListenerArn,
+          })
+        );
+        expect(request.isDone()).toBe(true);
+      });
+  });
+
+  test("Create operation returns non-root rule priority max + 1 for paginated response", () => {
     // This set of rules has the default, 3 and 5 rule priorities. We don't try to fill
     // in the gaps, we just create one that is 1 + the max. In this case, 6.
     const describeRulesFake = sinon.stub();
@@ -331,6 +422,20 @@ describe("ALB Rule Priority Generator", () => {
             },
           ],
         },
+        {
+          Priority: "48000",
+          Conditions: [],
+          RuleArn:
+            "arn:aws:elasticloadbalancing:us-west-2:000000000:listener-rule/app/rule",
+          IsDefault: true,
+          Actions: [
+            {
+              TargetGroupArn:
+                "arn:aws:elasticloadbalancing:us-west-2:000000000:targetgroup/tg",
+              Type: "forward",
+            },
+          ],
+        },
       ],
     });
 
@@ -347,6 +452,7 @@ describe("ALB Rule Priority Generator", () => {
         RequestId: testRequestId,
         ResourceProperties: {
           ListenerArn: testALBListenerArn,
+          RulePath: "/api",
         },
       })
       .expectResolve(() => {
