@@ -14,7 +14,6 @@ import (
 )
 
 var cli *client.CLI
-var aws *client.AWS
 var (
 	appName string
 	svcName string
@@ -39,9 +38,6 @@ var _ = BeforeSuite(func() {
 	cli = ecsCli
 	Expect(err).NotTo(HaveOccurred())
 
-	awsCli := client.NewAWS()
-	aws = awsCli
-
 	appName = fmt.Sprintf("e2e-addons-%d", time.Now().Unix())
 	svcName = "hello"
 
@@ -57,7 +53,7 @@ var _ = BeforeSuite(func() {
 var _ = AfterSuite(func() {
 	_, err := cli.AppDelete()
 	Expect(err).NotTo(HaveOccurred())
-	_ = aws.DeleteAllDBClusterSnapshots()
+	_ = client.NewAWS().DeleteAllDBClusterSnapshots()
 })
 
 func BeforeAll(fn func()) {
