@@ -167,7 +167,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				require.NoError(t, err)
 				m.mockUploader.EXPECT().Upload(mockS3Bucket, gomock.Any(), gomock.Any()).DoAndReturn(func(_, key string, _ io.Reader) (url string, err error) {
 					for _, cr := range crs {
-						if strings.Contains(key, strings.ToLower(cr.FunctionName())) {
+						if strings.Contains(key, strings.ToLower(cr.Name())) {
 							return "", nil
 						}
 					}
@@ -179,7 +179,9 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: customresource.LBWS,
+					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+						return customresource.LBWS(fs)
+					},
 				}
 			},
 		},
@@ -193,7 +195,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				require.NoError(t, err)
 				m.mockUploader.EXPECT().Upload(mockS3Bucket, gomock.Any(), gomock.Any()).DoAndReturn(func(_, key string, _ io.Reader) (url string, err error) {
 					for _, cr := range crs {
-						if strings.Contains(key, strings.ToLower(cr.FunctionName())) {
+						if strings.Contains(key, strings.ToLower(cr.Name())) {
 							return "", nil
 						}
 					}
@@ -205,7 +207,9 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: customresource.Backend,
+					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+						return customresource.Backend(fs)
+					},
 				}
 			},
 		},
@@ -219,7 +223,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				require.NoError(t, err)
 				m.mockUploader.EXPECT().Upload(mockS3Bucket, gomock.Any(), gomock.Any()).DoAndReturn(func(_, key string, _ io.Reader) (url string, err error) {
 					for _, cr := range crs {
-						if strings.Contains(key, strings.ToLower(cr.FunctionName())) {
+						if strings.Contains(key, strings.ToLower(cr.Name())) {
 							return "", nil
 						}
 					}
@@ -231,7 +235,9 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: customresource.Worker,
+					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+						return customresource.Worker(fs)
+					},
 				}
 			},
 		},
@@ -245,7 +251,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				require.NoError(t, err)
 				m.mockUploader.EXPECT().Upload(mockS3Bucket, gomock.Any(), gomock.Any()).DoAndReturn(func(_, key string, _ io.Reader) (url string, err error) {
 					for _, cr := range crs {
-						if strings.Contains(key, strings.ToLower(cr.FunctionName())) {
+						if strings.Contains(key, strings.ToLower(cr.Name())) {
 							return "", nil
 						}
 					}
@@ -257,7 +263,9 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 					svcDeployer: &svcDeployer{
 						workloadDeployer: deployer,
 					},
-					customResources: customresource.RDWS,
+					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+						return customresource.RDWS(fs)
+					},
 				}
 			},
 		},
@@ -271,7 +279,7 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 				require.NoError(t, err)
 				m.mockUploader.EXPECT().Upload(mockS3Bucket, gomock.Any(), gomock.Any()).DoAndReturn(func(_, key string, _ io.Reader) (url string, err error) {
 					for _, cr := range crs {
-						if strings.Contains(key, strings.ToLower(cr.FunctionName())) {
+						if strings.Contains(key, strings.ToLower(cr.Name())) {
 							return "", nil
 						}
 					}
@@ -281,7 +289,9 @@ func TestWorkloadDeployer_UploadArtifacts(t *testing.T) {
 			mockServiceDeployer: func(deployer *workloadDeployer) artifactsUploader {
 				return &jobDeployer{
 					workloadDeployer: deployer,
-					customResources:  customresource.ScheduledJob,
+					customResources: func(fs template.Reader) ([]*customresource.CustomResource, error) {
+						return customresource.ScheduledJob(fs)
+					},
 				}
 			},
 		},
@@ -469,6 +479,7 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 		inEnvironment     *config.Environment
 		inForceDeploy     bool
 		inDisableRollback bool
+		inRedirectToHTTPS *bool
 
 		// Cached variables.
 		inEnvironmentConfig func() *manifest.Environment
@@ -512,6 +523,24 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			},
 			wantErr: fmt.Errorf("cannot deploy service mockWkld without http.alias to environment mockEnv with certificate imported"),
 		},
+		"fail if http redirect to https configured without custom domain": {
+			inRedirectToHTTPS: aws.Bool(true),
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inEnvironmentConfig: func() *manifest.Environment {
+				return &manifest.Environment{}
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
+			},
+			wantErr: fmt.Errorf(`cannot configure http to https redirect without having a domain associated with the app "mockApp" or importing any certificates in env "mockEnv"`),
+		},
 		"cannot specify alias hosted zone when no certificates are imported in the env": {
 			inEnvironment: &config.Environment{
 				Name:   mockEnvName,
@@ -715,6 +744,23 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 			},
 			wantErr: fmt.Errorf("get version for app %s: %w", mockAppName, mockError),
 		},
+		"out of date app version": {
+			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v.0.99.0", nil)
+			},
+			wantErr: fmt.Errorf("alias is not compatible with application versions below v1.0.0"),
+		},
 		"fail to enable https alias because of incompatible app version": {
 			inAliases: manifest.Alias{AdvancedAliases: mockAlias},
 			inEnvironment: &config.Environment{
@@ -947,6 +993,58 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
 			},
 		},
+		"success with http redirect disabled and certs imported": {
+			inRedirectToHTTPS: aws.Bool(false),
+			inAliases: manifest.Alias{
+				AdvancedAliases: mockMultiAliases,
+			},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inEnvironmentConfig: func() *manifest.Environment {
+				envConfig := &manifest.Environment{}
+				envConfig.HTTPConfig.Public.Certificates = mockCertARNs
+				return envConfig
+			},
+			inApp: &config.Application{
+				Name: mockAppName,
+			},
+			mock: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
+				m.mockValidator.EXPECT().ValidateCertAliases([]string{"example.com", "foobar.com"}, mockCertARNs).Return(nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
+			},
+		},
+		"success with http redirect disabled and domain imported": {
+			inRedirectToHTTPS: aws.Bool(false),
+			inAliases: manifest.Alias{
+				AdvancedAliases: []manifest.AdvancedAlias{
+					{
+						Alias: aws.String("hi.mockDomain"),
+					},
+				},
+			},
+			inEnvironment: &config.Environment{
+				Name:   mockEnvName,
+				Region: "us-west-2",
+			},
+			inEnvironmentConfig: func() *manifest.Environment {
+				envConfig := &manifest.Environment{}
+				return envConfig
+			},
+			inApp: &config.Application{
+				Name:   mockAppName,
+				Domain: "mockDomain",
+			},
+			mock: func(m *deployMocks) {
+				m.mockEndpointGetter.EXPECT().ServiceDiscoveryEndpoint().Return("mockApp.local", nil)
+				m.mockEnvVersionGetter.EXPECT().Version().Return("v1.42.0", nil)
+				m.mockAppVersionGetter.EXPECT().Version().Return("v1.0.0", nil)
+				m.mockServiceDeployer.EXPECT().DeployService(gomock.Any(), "mockBucket", gomock.Any()).Return(nil)
+			},
+		},
 		"success with force update": {
 			inForceDeploy: true,
 			inEnvironment: &config.Environment{
@@ -1032,8 +1130,9 @@ func TestWorkloadDeployer_DeployWorkload(t *testing.T) {
 						},
 						RoutingRule: manifest.RoutingRuleConfigOrBool{
 							RoutingRuleConfiguration: manifest.RoutingRuleConfiguration{
-								Path:  aws.String("/"),
-								Alias: tc.inAliases,
+								Path:            aws.String("/"),
+								Alias:           tc.inAliases,
+								RedirectToHTTPS: tc.inRedirectToHTTPS,
 							},
 						},
 						NLBConfig: tc.inNLB,
