@@ -11,41 +11,71 @@ import (
 	"testing"
 	"time"
 
+	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation/stackset"
+
 	"github.com/aws/aws-sdk-go/aws"
 	sdkcloudformation "github.com/aws/aws-sdk-go/service/cloudformation"
 	awsecs "github.com/aws/aws-sdk-go/service/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/aws/cloudformation"
 	"github.com/aws/copilot-cli/internal/pkg/aws/ecs"
 	"github.com/aws/copilot-cli/internal/pkg/deploy/cloudformation/mocks"
-	"github.com/aws/copilot-cli/internal/pkg/term/progress"
 	"github.com/golang/mock/gomock"
 	"github.com/stretchr/testify/require"
 )
 
+func TestIsEmptyErr(t *testing.T) {
+	testCases := map[string]struct {
+		err    error
+		wanted bool
+	}{
+		"should return true when the error is an ErrStackSetNotFound": {
+			err:    &stackset.ErrStackSetNotFound{},
+			wanted: true,
+		},
+		"should return true when the error is an ErrStackSetInstancesNotFound": {
+			err:    &stackset.ErrStackSetInstancesNotFound{},
+			wanted: true,
+		},
+		"should return false on any other error": {
+			err: errors.New("some error"),
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			require.Equal(t, tc.wanted, IsEmptyErr(tc.err))
+		})
+	}
+}
+
 type mockFileWriter struct {
 	io.Writer
 }
 
 func (m mockFileWriter) Fd() uintptr { return 0 }
 
-func testDeployWorkload_OnPushToS3Failure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_OnPushToS3Failure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 	wantedErr := errors.New("some error")
 	mS3Client := mocks.NewMocks3Client(ctrl)
 	mS3Client.EXPECT().Upload("mockBucket", gomock.Any(), gomock.Any()).Return("", wantedErr)
-	client := CloudFormation{s3Client: mS3Client}
+
 	buf := new(strings.Builder)
+	client := CloudFormation{
+		s3Client: mS3Client,
+		console:  mockFileWriter{Writer: buf},
+	}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.True(t, errors.Is(err, wantedErr), `expected returned error to be wrapped with "some error"`)
 }
 
-func testDeployWorkload_OnCreateChangeSetFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_OnCreateChangeSetFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -55,17 +85,17 @@ func testDeployWorkload_OnCreateChangeSetFailure(t *testing.T, when func(w progr
 	m := mocks.NewMockcfnClient(ctrl)
 	m.EXPECT().Create(gomock.Any()).Return("", wantedErr)
 	m.EXPECT().ErrorEvents(gomock.Any()).Return(nil, nil)
-	client := CloudFormation{cfnClient: m, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.True(t, errors.Is(err, wantedErr), `expected returned error to be wrapped with "some error"`)
 }
 
-func testDeployWorkload_OnUpdateChangeSetFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_OnUpdateChangeSetFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -76,17 +106,17 @@ func testDeployWorkload_OnUpdateChangeSetFailure(t *testing.T, when func(w progr
 	m.EXPECT().Create(gomock.Any()).Return("", &cloudformation.ErrStackAlreadyExists{})
 	m.EXPECT().Update(gomock.Any()).Return("", wantedErr)
 	m.EXPECT().ErrorEvents(gomock.Any()).Return(nil, nil)
-	client := CloudFormation{cfnClient: m, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.True(t, errors.Is(err, wantedErr), `expected returned error to be wrapped with "some error"`)
 }
 
-func testDeployWorkload_OnDescribeChangeSetFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_OnDescribeChangeSetFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -95,17 +125,17 @@ func testDeployWorkload_OnDescribeChangeSetFailure(t *testing.T, when func(w pro
 	m := mocks.NewMockcfnClient(ctrl)
 	m.EXPECT().Create(gomock.Any()).Return("1234", nil)
 	m.EXPECT().DescribeChangeSet(gomock.Any(), gomock.Any()).Return(nil, errors.New("DescribeChangeSet error"))
-	client := CloudFormation{cfnClient: m, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.EqualError(t, err, "DescribeChangeSet error")
 }
 
-func testDeployWorkload_OnTemplateBodyFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_OnTemplateBodyFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -115,17 +145,17 @@ func testDeployWorkload_OnTemplateBodyFailure(t *testing.T, when func(w progress
 	m.EXPECT().Create(gomock.Any()).Return("1234", nil)
 	m.EXPECT().DescribeChangeSet(gomock.Any(), gomock.Any()).Return(&cloudformation.ChangeSetDescription{}, nil)
 	m.EXPECT().TemplateBodyFromChangeSet(gomock.Any(), gomock.Any()).Return("", errors.New("TemplateBody error"))
-	client := CloudFormation{cfnClient: m, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.EqualError(t, err, "TemplateBody error")
 }
 
-func testDeployWorkload_StackStreamerFailureShouldCancelRenderer(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_StackStreamerFailureShouldCancelRenderer(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -137,17 +167,17 @@ func testDeployWorkload_StackStreamerFailureShouldCancelRenderer(t *testing.T, w
 	m.EXPECT().DescribeChangeSet(gomock.Any(), gomock.Any()).Return(&cloudformation.ChangeSetDescription{}, nil)
 	m.EXPECT().TemplateBodyFromChangeSet(gomock.Any(), gomock.Any()).Return("", nil)
 	m.EXPECT().DescribeStackEvents(gomock.Any()).Return(nil, wantedErr)
-	client := CloudFormation{cfnClient: m, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.True(t, errors.Is(err, wantedErr), "expected streamer error to be wrapped and returned")
 }
 
-func testDeployWorkload_StreamUntilStackCreationFails(t *testing.T, stackName string, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_StreamUntilStackCreationFails(t *testing.T, stackName string, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -171,17 +201,17 @@ func testDeployWorkload_StreamUntilStackCreationFails(t *testing.T, stackName st
 	m.EXPECT().Describe(stackName).Return(&cloudformation.StackDescription{
 		StackStatus: aws.String("CREATE_FAILED"),
 	}, nil)
-	client := CloudFormation{cfnClient: m, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.EqualError(t, err, fmt.Sprintf("stack %s did not complete successfully and exited with status CREATE_FAILED", stackName))
 }
 
-func testDeployWorkload_RenderNewlyCreatedStackWithECSService(t *testing.T, stackName string, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_RenderNewlyCreatedStackWithECSService(t *testing.T, stackName string, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -251,11 +281,11 @@ Resources:
 	mockCFN.EXPECT().Describe(stackName).Return(&cloudformation.StackDescription{
 		StackStatus: aws.String("CREATE_COMPLETE"),
 	}, nil)
-	client := CloudFormation{cfnClient: mockCFN, ecsClient: mockECS, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: mockCFN, ecsClient: mockECS, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.NoError(t, err)
@@ -264,7 +294,7 @@ Resources:
 	require.Contains(t, buf.String(), "[completed]", "Rollout state of service should be rendered")
 }
 
-func testDeployWorkload_WithEnvControllerRenderer_NoStackUpdates(t *testing.T, svcStackName string, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_WithEnvControllerRenderer_NoStackUpdates(t *testing.T, svcStackName string, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -331,18 +361,18 @@ Resources:
 	mockCFN.EXPECT().Describe(svcStackName).Return(&cloudformation.StackDescription{
 		StackStatus: aws.String("CREATE_COMPLETE"),
 	}, nil)
-	client := CloudFormation{cfnClient: mockCFN, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: mockCFN, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.NoError(t, err)
 	require.Contains(t, buf.String(), "Updating environment", "env stack description is rendered")
 }
 
-func testDeployWorkload_RenderNewlyCreatedStackWithAddons(t *testing.T, stackName string, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployWorkload_RenderNewlyCreatedStackWithAddons(t *testing.T, stackName string, when func(cf CloudFormation) error) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 	m := mocks.NewMockcfnClient(ctrl)
@@ -452,11 +482,11 @@ Resources:
 			},
 		},
 	}, nil).AnyTimes()
-	client := CloudFormation{cfnClient: m, s3Client: mS3Client}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, s3Client: mS3Client, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.NoError(t, err)
@@ -465,7 +495,7 @@ Resources:
 	require.Contains(t, buf.String(), "A DynamoDB table to store data")
 }
 
-func testDeployTask_OnCreateChangeSetFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_OnCreateChangeSetFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -473,17 +503,17 @@ func testDeployTask_OnCreateChangeSetFailure(t *testing.T, when func(w progress.
 	m := mocks.NewMockcfnClient(ctrl)
 	m.EXPECT().Create(gomock.Any()).Return("", wantedErr)
 	m.EXPECT().ErrorEvents(gomock.Any()).Return(nil, nil)
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.True(t, errors.Is(err, wantedErr), `expected returned error to be wrapped with "some error"`)
 }
 
-func testDeployTask_ReturnNilOnEmptyChangeSetWhileUpdatingStack(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_ReturnNilOnEmptyChangeSetWhileUpdatingStack(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -492,17 +522,17 @@ func testDeployTask_ReturnNilOnEmptyChangeSetWhileUpdatingStack(t *testing.T, wh
 	m.EXPECT().Create(gomock.Any()).Return("", &cloudformation.ErrStackAlreadyExists{})
 	m.EXPECT().Update(gomock.Any()).Return("", wantedErr)
 	m.EXPECT().ErrorEvents(gomock.Any()).Return(nil, nil)
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.Nil(t, err, "should not fail if the changeset is empty")
 }
 
-func testDeployTask_OnUpdateChangeSetFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_OnUpdateChangeSetFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -511,34 +541,34 @@ func testDeployTask_OnUpdateChangeSetFailure(t *testing.T, when func(w progress.
 	m.EXPECT().Create(gomock.Any()).Return("", &cloudformation.ErrStackAlreadyExists{})
 	m.EXPECT().Update(gomock.Any()).Return("", wantedErr)
 	m.EXPECT().ErrorEvents(gomock.Any()).Return(nil, nil)
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.True(t, errors.Is(err, wantedErr), `expected returned error to be wrapped with "some error"`)
 }
 
-func testDeployTask_OnDescribeChangeSetFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_OnDescribeChangeSetFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 	m := mocks.NewMockcfnClient(ctrl)
 	m.EXPECT().Create(gomock.Any()).Return("1234", nil)
 	m.EXPECT().DescribeChangeSet(gomock.Any(), gomock.Any()).Return(nil, errors.New("DescribeChangeSet error"))
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.EqualError(t, err, "DescribeChangeSet error")
 }
 
-func testDeployTask_OnTemplateBodyFailure(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_OnTemplateBodyFailure(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -546,17 +576,17 @@ func testDeployTask_OnTemplateBodyFailure(t *testing.T, when func(w progress.Fil
 	m.EXPECT().Create(gomock.Any()).Return("1234", nil)
 	m.EXPECT().DescribeChangeSet(gomock.Any(), gomock.Any()).Return(&cloudformation.ChangeSetDescription{}, nil)
 	m.EXPECT().TemplateBodyFromChangeSet(gomock.Any(), gomock.Any()).Return("", errors.New("TemplateBody error"))
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.EqualError(t, err, "TemplateBody error")
 }
 
-func testDeployTask_StackStreamerFailureShouldCancelRenderer(t *testing.T, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_StackStreamerFailureShouldCancelRenderer(t *testing.T, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -566,17 +596,17 @@ func testDeployTask_StackStreamerFailureShouldCancelRenderer(t *testing.T, when
 	m.EXPECT().DescribeChangeSet(gomock.Any(), gomock.Any()).Return(&cloudformation.ChangeSetDescription{}, nil)
 	m.EXPECT().TemplateBodyFromChangeSet(gomock.Any(), gomock.Any()).Return("", nil)
 	m.EXPECT().DescribeStackEvents(gomock.Any()).Return(nil, wantedErr)
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.True(t, errors.Is(err, wantedErr), "expected streamer error to be wrapped and returned")
 }
 
-func testDeployTask_StreamUntilStackCreationFails(t *testing.T, stackName string, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_StreamUntilStackCreationFails(t *testing.T, stackName string, when func(cf CloudFormation) error) {
 	// GIVEN
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -598,17 +628,17 @@ func testDeployTask_StreamUntilStackCreationFails(t *testing.T, stackName string
 	m.EXPECT().Describe(stackName).Return(&cloudformation.StackDescription{
 		StackStatus: aws.String("CREATE_FAILED"),
 	}, nil)
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.EqualError(t, err, fmt.Sprintf("stack %s did not complete successfully and exited with status CREATE_FAILED", stackName))
 }
 
-func testDeployTask_RenderNewlyCreatedStackWithAddons(t *testing.T, stackName string, when func(w progress.FileWriter, cf CloudFormation) error) {
+func testDeployTask_RenderNewlyCreatedStackWithAddons(t *testing.T, stackName string, when func(cf CloudFormation) error) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
 	m := mocks.NewMockcfnClient(ctrl)
@@ -716,11 +746,11 @@ Resources:
 			},
 		},
 	}, nil).AnyTimes()
-	client := CloudFormation{cfnClient: m}
 	buf := new(strings.Builder)
+	client := CloudFormation{cfnClient: m, console: mockFileWriter{Writer: buf}}
 
 	// WHEN
-	err := when(mockFileWriter{Writer: buf}, client)
+	err := when(client)
 
 	// THEN
 	require.NoError(t, err)
