@@ -92,6 +92,7 @@ func NewLoadBalancedWebService(conf LoadBalancedWebServiceConfig,
 				name:        aws.StringValue(conf.Manifest.Name),
 				env:         aws.StringValue(conf.EnvManifest.Name),
 				app:         conf.App.Name,
+				permBound:   conf.App.PermissionsBoundary,
 				rc:          conf.RuntimeConfig,
 				image:       conf.Manifest.ImageConfig.Image,
 				rawManifest: conf.RawManifest,
@@ -185,6 +186,11 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 	if err != nil {
 		return "", err
 	}
+	httpRedirect := true
+	if s.manifest.RoutingRule.RedirectToHTTPS != nil {
+		httpRedirect = aws.BoolValue(s.manifest.RoutingRule.RedirectToHTTPS)
+	}
+	_, targetContainerPort := s.httpLoadBalancerTarget()
 	content, err := s.parser.ParseLoadBalancedWebService(template.WorkloadOpts{
 		AppName:            s.app,
 		EnvName:            s.env,
@@ -192,20 +198,24 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 		SerializedManifest: string(s.rawManifest),
 		EnvVersion:         s.rc.EnvVersion,
 
-		Variables:                s.manifest.TaskConfig.Variables,
-		Secrets:                  convertSecrets(s.manifest.TaskConfig.Secrets),
-		Aliases:                  aliases,
-		HTTPSListener:            s.httpsEnabled,
-		NestedStack:              addonsOutputs,
-		AddonsExtraParams:        addonsParams,
-		Sidecars:                 sidecars,
-		LogConfig:                convertLogging(s.manifest.Logging),
-		DockerLabels:             s.manifest.ImageConfig.Image.DockerLabels,
-		Autoscaling:              autoscaling,
-		CapacityProviders:        capacityProviders,
-		DesiredCountOnSpot:       desiredCountOnSpot,
-		ExecuteCommand:           convertExecuteCommand(&s.manifest.ExecuteCommand),
-		WorkloadType:             manifest.LoadBalancedWebServiceType,
+		Variables:          s.manifest.TaskConfig.Variables,
+		Secrets:            convertSecrets(s.manifest.TaskConfig.Secrets),
+		Aliases:            aliases,
+		HTTPSListener:      s.httpsEnabled,
+		HTTPRedirect:       httpRedirect,
+		NestedStack:        addonsOutputs,
+		AddonsExtraParams:  addonsParams,
+		Sidecars:           sidecars,
+		LogConfig:          convertLogging(s.manifest.Logging),
+		DockerLabels:       s.manifest.ImageConfig.Image.DockerLabels,
+		Autoscaling:        autoscaling,
+		CapacityProviders:  capacityProviders,
+		DesiredCountOnSpot: desiredCountOnSpot,
+		ExecuteCommand:     convertExecuteCommand(&s.manifest.ExecuteCommand),
+		WorkloadType:       manifest.LoadBalancedWebServiceType,
+		HTTPTargetContainer: template.HTTPTargetContainer{
+			Port: aws.StringValue(targetContainerPort),
+		},
 		HealthCheck:              convertContainerHealthCheck(s.manifest.ImageConfig.HealthCheck),
 		HTTPHealthCheck:          convertHTTPHealthCheck(&s.manifest.RoutingRule.HealthCheck),
 		DeregistrationDelay:      deregistrationDelay,
@@ -229,16 +239,17 @@ func (s *LoadBalancedWebService) Template() (string, error) {
 		Observability: template.ObservabilityOpts{
 			Tracing: strings.ToUpper(aws.StringValue(s.manifest.Observability.Tracing)),
 		},
-		HostedZoneAliases: aliasesFor,
+		HostedZoneAliases:   aliasesFor,
+		PermissionsBoundary: s.permBound,
 	})
 	if err != nil {
 		return "", err
 	}
-	overridenTpl, err := s.taskDefOverrideFunc(convertTaskDefOverrideRules(s.manifest.TaskDefOverrides), content.Bytes())
+	overriddenTpl, err := s.taskDefOverrideFunc(convertTaskDefOverrideRules(s.manifest.TaskDefOverrides), content.Bytes())
 	if err != nil {
 		return "", fmt.Errorf("apply task definition overrides: %w", err)
 	}
-	return string(overridenTpl), nil
+	return string(overriddenTpl), nil
 }
 
 func (s *LoadBalancedWebService) httpLoadBalancerTarget() (targetContainer *string, targetPort *string) {
