@@ -50,6 +50,42 @@ func TestRoutingRuleConfigOrBool_Disabled(t *testing.T) {
 	}
 }
 
+func TestAlias_HostedZones(t *testing.T) {
+	testCases := map[string]struct {
+		in     Alias
+		wanted []string
+	}{
+		"no hosted zone": {
+			in: Alias{
+				AdvancedAliases: []AdvancedAlias{},
+			},
+			wanted: []string{},
+		},
+		"with hosted zones": {
+			in: Alias{
+				AdvancedAliases: []AdvancedAlias{
+					{
+						HostedZone: aws.String("mockHostedZone1"),
+					},
+					{
+						HostedZone: aws.String("mockHostedZone2"),
+					},
+				},
+			},
+			wanted: []string{"mockHostedZone1", "mockHostedZone2"},
+		},
+	}
+
+	for name, tc := range testCases {
+		t.Run(name, func(t *testing.T) {
+			// WHEN
+			got := tc.in.HostedZones()
+			// THEN
+			require.ElementsMatch(t, tc.wanted, got)
+		})
+	}
+}
+
 func TestAlias_UnmarshalYAML(t *testing.T) {
 	testCases := map[string]struct {
 		inContent []byte
@@ -60,7 +96,7 @@ func TestAlias_UnmarshalYAML(t *testing.T) {
 		"Alias specified in string": {
 			inContent: []byte(`alias: foobar.com`),
 			wantedStruct: Alias{
-				StringSliceOrString: stringSliceOrString{
+				StringSliceOrString: StringSliceOrString{
 					String: aws.String("foobar.com"),
 				},
 			},
@@ -70,7 +106,7 @@ func TestAlias_UnmarshalYAML(t *testing.T) {
   - example.com
   - v1.example.com`),
 			wantedStruct: Alias{
-				StringSliceOrString: stringSliceOrString{
+				StringSliceOrString: StringSliceOrString{
 					StringSlice: []string{"example.com", "v1.example.com"},
 				},
 				AdvancedAliases: []AdvancedAlias{},
@@ -97,7 +133,7 @@ func TestAlias_UnmarshalYAML(t *testing.T) {
 			inContent: []byte(`alias:
   foo: bar`),
 			wantedStruct: Alias{
-				StringSliceOrString: stringSliceOrString{},
+				StringSliceOrString: StringSliceOrString{},
 				AdvancedAliases:     []AdvancedAlias{},
 			},
 			wantedError: errUnmarshalAlias,
@@ -108,7 +144,7 @@ func TestAlias_UnmarshalYAML(t *testing.T) {
 		t.Run(name, func(t *testing.T) {
 			r := RoutingRuleConfiguration{
 				Alias: Alias{
-					StringSliceOrString: stringSliceOrString{
+					StringSliceOrString: StringSliceOrString{
 						String: aws.String("wrong"),
 					},
 				},
@@ -138,7 +174,7 @@ func TestAlias_IsEmpty(t *testing.T) {
 		},
 		"non empty alias": {
 			in: Alias{
-				StringSliceOrString: stringSliceOrString{
+				StringSliceOrString: StringSliceOrString{
 					String: aws.String("alias test"),
 				},
 			},
@@ -163,7 +199,7 @@ func TestAlias_ToString(t *testing.T) {
 	}{
 		"alias using string": {
 			inAlias: Alias{
-				StringSliceOrString: stringSliceOrString{
+				StringSliceOrString: StringSliceOrString{
 					String: stringP("example.com"),
 				},
 			},
@@ -171,7 +207,7 @@ func TestAlias_ToString(t *testing.T) {
 		},
 		"alias using string slice": {
 			inAlias: Alias{
-				StringSliceOrString: stringSliceOrString{
+				StringSliceOrString: StringSliceOrString{
 					StringSlice: []string{"example.com", "v1.example.com"},
 				},
 			},
@@ -209,7 +245,7 @@ func TestAlias_ToStringSlice(t *testing.T) {
 	}{
 		"alias using string": {
 			inAlias: Alias{
-				StringSliceOrString: stringSliceOrString{
+				StringSliceOrString: StringSliceOrString{
 					String: stringP("example.com"),
 				},
 			},
@@ -217,7 +253,7 @@ func TestAlias_ToStringSlice(t *testing.T) {
 		},
 		"alias using string slice": {
 			inAlias: Alias{
-				StringSliceOrString: stringSliceOrString{
+				StringSliceOrString: StringSliceOrString{
 					StringSlice: []string{"example.com", "v1.example.com"},
 				},
 			},
