@@ -16,7 +16,7 @@ import (
 
 func TestUnmarshalSvc(t *testing.T) {
 	perc := Percentage(70)
-	mockConfig := ScalingConfigOrPercentage{
+	mockConfig := ScalingConfigOrT[Percentage]{
 		Value: &perc,
 	}
 	testCases := map[string]struct {
@@ -102,7 +102,7 @@ environments:
 							RoutingRuleConfiguration: RoutingRuleConfiguration{
 								Alias: Alias{
 									AdvancedAliases: []AdvancedAlias{},
-									StringSliceOrString: stringSliceOrString{
+									StringSliceOrString: StringSliceOrString{
 										StringSlice: []string{
 											"foobar.com",
 											"v1.foobar.com",
@@ -393,7 +393,7 @@ type: 'OH NO'
 				require.EqualError(t, err, tc.wantedErr.Error())
 			} else {
 				require.NoError(t, err)
-				tc.requireCorrectValues(t, m)
+				tc.requireCorrectValues(t, m.Manifest())
 			}
 		})
 	}
@@ -403,10 +403,11 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 	var (
 		perc               = Percentage(70)
 		timeMinute         = 60 * time.Second
-		mockResponseTime   = 500 * time.Millisecond
+		reqNum             = 1000
+		responseTime       = 500 * time.Millisecond
 		mockRange          = IntRangeBand("1-10")
-		mockAdvancedConfig = ScalingConfigOrPercentage{
-			ScalingConfig: AdvancedScalingConfig{
+		mockAdvancedConfig = ScalingConfigOrT[Percentage]{
+			ScalingConfig: AdvancedScalingConfig[Percentage]{
 				Value: &perc,
 				Cooldown: Cooldown{
 					ScaleInCooldown:  &timeMinute,
@@ -414,13 +415,19 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 				},
 			},
 		}
-		mockConfig = ScalingConfigOrPercentage{
+		mockConfig = ScalingConfigOrT[Percentage]{
 			Value: &perc,
 		}
 		mockCooldown = Cooldown{
 			ScaleInCooldown:  &timeMinute,
 			ScaleOutCooldown: &timeMinute,
 		}
+		mockRequests = ScalingConfigOrT[int]{
+			Value: &reqNum,
+		}
+		mockResponseTime = ScalingConfigOrT[time.Duration]{
+			Value: &responseTime,
+		}
 	)
 
 	testCases := map[string]struct {
@@ -453,8 +460,8 @@ func TestCount_UnmarshalYAML(t *testing.T) {
 					Range:        Range{Value: &mockRange},
 					CPU:          mockAdvancedConfig,
 					Memory:       mockConfig,
-					Requests:     aws.Int(1000),
-					ResponseTime: &mockResponseTime,
+					Requests:     mockRequests,
+					ResponseTime: mockResponseTime,
 				},
 			},
 		},
