@@ -347,7 +347,7 @@ func (cfg securityGroupsConfig) validate() error {
 }
 
 // validate returns nil if environmentCDNConfig is configured correctly.
-func (cfg environmentCDNConfig) validate() error {
+func (cfg EnvironmentCDNConfig) validate() error {
 	if cfg.Config.isEmpty() {
 		return nil
 	}
@@ -365,8 +365,14 @@ func (i RestrictiveIngress) validate() error {
 }
 
 // validate returns nil if advancedCDNConfig is configured correctly.
-func (cfg advancedCDNConfig) validate() error {
+func (cfg AdvancedCDNConfig) validate() error {
 	if cfg.Certificate == nil {
+		if aws.BoolValue(cfg.TerminateTLS) {
+			return &errFieldMustBeSpecified{
+				missingField:      "certificate",
+				conditionalFields: []string{"terminate_tls"},
+			}
+		}
 		return nil
 	}
 	certARN, err := arn.Parse(*cfg.Certificate)
