@@ -31,16 +31,23 @@ func TestRepository_BuildAndPush(t *testing.T) {
 	}
 
 	testCases := map[string]struct {
-		inRepoName       string
-		inDockerfilePath string
-		inMockDocker     func(m *mocks.MockContainerLoginBuildPusher)
+		inURI        string
+		inMockDocker func(m *mocks.MockContainerLoginBuildPusher)
 
 		mockRegistry func(m *mocks.MockRegistry)
 
 		wantedError  error
 		wantedDigest string
 	}{
+		"failed to get repo URI": {
+			mockRegistry: func(m *mocks.MockRegistry) {
+				m.EXPECT().RepositoryURI(inRepoName).Return("", errors.New("some error"))
+			},
+			inMockDocker: func(m *mocks.MockContainerLoginBuildPusher) {},
+			wantedError:  errors.New("get repository URI: some error"),
+		},
 		"failed to get auth": {
+			inURI: defaultDockerArguments.URI,
 			mockRegistry: func(m *mocks.MockRegistry) {
 				m.EXPECT().Auth().Return("", "", errors.New("error getting auth"))
 			},
@@ -53,6 +60,7 @@ func TestRepository_BuildAndPush(t *testing.T) {
 			wantedError: errors.New("get auth: error getting auth"),
 		},
 		"failed to build image": {
+			inURI: defaultDockerArguments.URI,
 			mockRegistry: func(m *mocks.MockRegistry) {
 				m.EXPECT().Auth().Return("", "", nil).AnyTimes()
 			},
@@ -64,6 +72,7 @@ func TestRepository_BuildAndPush(t *testing.T) {
 			wantedError: fmt.Errorf("build Dockerfile at %s: error building image", inDockerfilePath),
 		},
 		"failed to login": {
+			inURI: defaultDockerArguments.URI,
 			mockRegistry: func(m *mocks.MockRegistry) {
 				m.EXPECT().Auth().Return("my-name", "my-pwd", nil)
 			},
@@ -76,6 +85,7 @@ func TestRepository_BuildAndPush(t *testing.T) {
 			wantedError: fmt.Errorf("login to repo %s: error logging in", inRepoName),
 		},
 		"failed to push": {
+			inURI: defaultDockerArguments.URI,
 			mockRegistry: func(m *mocks.MockRegistry) {
 				m.EXPECT().Auth().Times(1)
 			},
@@ -88,6 +98,7 @@ func TestRepository_BuildAndPush(t *testing.T) {
 			wantedError: errors.New("push to repo my-repo: error pushing image"),
 		},
 		"push with ecr-login": {
+			inURI: defaultDockerArguments.URI,
 			inMockDocker: func(m *mocks.MockContainerLoginBuildPusher) {
 				m.EXPECT().Build(&defaultDockerArguments).Return(nil).Times(1)
 				m.EXPECT().IsEcrCredentialHelperEnabled(defaultDockerArguments.URI).Return(true)
@@ -97,6 +108,7 @@ func TestRepository_BuildAndPush(t *testing.T) {
 		},
 		"success": {
 			mockRegistry: func(m *mocks.MockRegistry) {
+				m.EXPECT().RepositoryURI(inRepoName).Return(defaultDockerArguments.URI, nil)
 				m.EXPECT().Auth().Return("my-name", "my-pwd", nil).Times(1)
 			},
 			inMockDocker: func(m *mocks.MockContainerLoginBuildPusher) {
@@ -126,8 +138,7 @@ func TestRepository_BuildAndPush(t *testing.T) {
 			repo := &Repository{
 				name:     inRepoName,
 				registry: mockRepoGetter,
-
-				uri: mockRepoURI,
+				uri:      tc.inURI,
 			}
 
 			digest, err := repo.BuildAndPush(mockDocker, &dockerengine.BuildArguments{
