@@ -235,7 +235,37 @@ func TestEnvRunner_Run(t *testing.T) {
 				},
 			},
 		},
-		"run in env with windows os success": {
+		"run in env with windows os success 2019 core": {
+			count:     1,
+			groupName: "my-task",
+			os:        "WINDOWS_SERVER_2019_CORE",
+			arch:      "X86_64",
+
+			MockClusterGetter: mockClusterGetter,
+			MockVPCGetter: func(m *mocks.MockVPCGetter) {
+				m.EXPECT().SecurityGroups(filtersForSecurityGroup).Return([]string{"sg-1", "sg-2"}, nil)
+			},
+			mockStarter: func(m *mocks.MockRunner) {
+				m.EXPECT().RunTask(ecs.RunTaskInput{
+					Cluster:         "cluster-1",
+					Count:           1,
+					Subnets:         []string{"subnet-0789ab", "subnet-0123cd"},
+					SecurityGroups:  []string{"sg-1", "sg-2"},
+					TaskFamilyName:  taskFamilyName("my-task"),
+					StartedBy:       startedBy,
+					PlatformVersion: "1.0.0",
+					EnableExec:      true,
+				}).Return([]*ecs.Task{&taskWithENI}, nil)
+			},
+			mockEnvironmentDescriber: mockEnvironmentDescriberValid,
+			wantedTasks: []*Task{
+				{
+					TaskARN: "task-1",
+					ENI:     "eni-1",
+				},
+			},
+		},
+		"run in env with windows os success 2019 full": {
 			count:     1,
 			groupName: "my-task",
 			os:        "WINDOWS_SERVER_2019_FULL",
@@ -265,6 +295,66 @@ func TestEnvRunner_Run(t *testing.T) {
 				},
 			},
 		},
+		"run in env with windows os success 2022 core": {
+			count:     1,
+			groupName: "my-task",
+			os:        "WINDOWS_SERVER_2022_CORE",
+			arch:      "X86_64",
+
+			MockClusterGetter: mockClusterGetter,
+			MockVPCGetter: func(m *mocks.MockVPCGetter) {
+				m.EXPECT().SecurityGroups(filtersForSecurityGroup).Return([]string{"sg-1", "sg-2"}, nil)
+			},
+			mockStarter: func(m *mocks.MockRunner) {
+				m.EXPECT().RunTask(ecs.RunTaskInput{
+					Cluster:         "cluster-1",
+					Count:           1,
+					Subnets:         []string{"subnet-0789ab", "subnet-0123cd"},
+					SecurityGroups:  []string{"sg-1", "sg-2"},
+					TaskFamilyName:  taskFamilyName("my-task"),
+					StartedBy:       startedBy,
+					PlatformVersion: "1.0.0",
+					EnableExec:      true,
+				}).Return([]*ecs.Task{&taskWithENI}, nil)
+			},
+			mockEnvironmentDescriber: mockEnvironmentDescriberValid,
+			wantedTasks: []*Task{
+				{
+					TaskARN: "task-1",
+					ENI:     "eni-1",
+				},
+			},
+		},
+		"run in env with windows os success 2022 full": {
+			count:     1,
+			groupName: "my-task",
+			os:        "WINDOWS_SERVER_2022_FULL",
+			arch:      "X86_64",
+
+			MockClusterGetter: mockClusterGetter,
+			MockVPCGetter: func(m *mocks.MockVPCGetter) {
+				m.EXPECT().SecurityGroups(filtersForSecurityGroup).Return([]string{"sg-1", "sg-2"}, nil)
+			},
+			mockStarter: func(m *mocks.MockRunner) {
+				m.EXPECT().RunTask(ecs.RunTaskInput{
+					Cluster:         "cluster-1",
+					Count:           1,
+					Subnets:         []string{"subnet-0789ab", "subnet-0123cd"},
+					SecurityGroups:  []string{"sg-1", "sg-2"},
+					TaskFamilyName:  taskFamilyName("my-task"),
+					StartedBy:       startedBy,
+					PlatformVersion: "1.0.0",
+					EnableExec:      true,
+				}).Return([]*ecs.Task{&taskWithENI}, nil)
+			},
+			mockEnvironmentDescriber: mockEnvironmentDescriberValid,
+			wantedTasks: []*Task{
+				{
+					TaskARN: "task-1",
+					ENI:     "eni-1",
+				},
+			},
+		},
 		"eni information not found for several tasks": {
 			count:     1,
 			groupName: "my-task",
