@@ -45,9 +45,13 @@ const (
 	PrivateSubnetsPlacement = "PrivateSubnets"
 
 	// RuntimePlatform configuration.
-	OSLinux             = "LINUX"
-	OSWindowsServerFull = "WINDOWS_SERVER_2019_FULL"
-	OSWindowsServerCore = "WINDOWS_SERVER_2019_CORE"
+	OSLinux                 = "LINUX"
+	OSWindowsServerFull     = OSWindowsServer2019Full // Alias 2019 as Default WindowsSever Full platform.
+	OSWindowsServerCore     = OSWindowsServer2019Core // Alias 2019 as Default WindowsSever Core platform.
+	OSWindowsServer2019Full = "WINDOWS_SERVER_2019_FULL"
+	OSWindowsServer2019Core = "WINDOWS_SERVER_2019_CORE"
+	OSWindowsServer2022Full = "WINDOWS_SERVER_2022_FULL"
+	OSWindowsServer2022Core = "WINDOWS_SERVER_2022_CORE"
 
 	ArchX86   = "X86_64"
 	ArchARM64 = "ARM64"
@@ -58,6 +62,11 @@ const (
 	snsARNPattern = "arn:%s:sns:%s:%s:%s-%s-%s-%s"
 )
 
+// Constants for stack resource logical IDs
+const (
+	LogicalIDHTTPListenerRuleWithDomain = "HTTPListenerRuleWithDomain"
+)
+
 var (
 	// Template names under "workloads/partials/cf/".
 	partialsWorkloadCFTemplateNames = []string{
@@ -96,7 +105,7 @@ var (
 
 	// Operating systems to determine Fargate platform versions.
 	osFamiliesForPV100 = []string{
-		OSWindowsServerFull, OSWindowsServerCore,
+		OSWindowsServer2019Full, OSWindowsServer2019Core, OSWindowsServer2022Full, OSWindowsServer2022Core,
 	}
 )
 
@@ -199,9 +208,23 @@ type LogConfigOpts struct {
 	Secrets        map[string]Secret
 }
 
+// HTTPTargetContainer represents the target group of a load balancer that points to a container.
+type HTTPTargetContainer struct {
+	Port string // Port of the container.
+}
+
+// IsHTTPS returns true if the target container's port is 443.
+func (tg HTTPTargetContainer) IsHTTPS() bool {
+	return tg.Port == "443"
+}
+
 // HTTPHealthCheckOpts holds configuration that's needed for HTTP Health Check.
 type HTTPHealthCheckOpts struct {
-	HealthCheckPath     string
+	// Fields with defaults always set.
+	HealthCheckPath string
+	GracePeriod     int64
+
+	// Optional.
 	Port                string
 	SuccessCodes        string
 	HealthyThreshold    *int64
@@ -209,7 +232,6 @@ type HTTPHealthCheckOpts struct {
 	Interval            *int64
 	Timeout             *int64
 	DeregistrationDelay *int64
-	GracePeriod         *int64
 }
 
 // A Secret represents an SSM or SecretsManager secret that can be rendered in CloudFormation.
@@ -384,7 +406,8 @@ type PublishOpts struct {
 
 // Topic holds information needed to render a SNSTopic in a container definition.
 type Topic struct {
-	Name *string
+	Name            *string
+	FIFOTopicConfig *FIFOTopicConfig
 
 	Region    string
 	Partition string
@@ -394,6 +417,11 @@ type Topic struct {
 	Svc       string
 }
 
+// Fifo holds configuration needed if the topic is FIFO.
+type FIFOTopicConfig struct {
+	ContentBasedDeduplication *bool
+}
+
 // SubscribeOpts holds configuration needed if the service has subscriptions.
 type SubscribeOpts struct {
 	Topics []*TopicSubscription
@@ -420,10 +448,18 @@ type TopicSubscription struct {
 
 // SQSQueue holds information needed to render a SQS Queue in a container definition.
 type SQSQueue struct {
-	Retention  *int64
-	Delay      *int64
-	Timeout    *int64
-	DeadLetter *DeadLetterQueue
+	Retention       *int64
+	Delay           *int64
+	Timeout         *int64
+	DeadLetter      *DeadLetterQueue
+	FIFOQueueConfig *FIFOQueueConfig
+}
+
+// FifoAdvanceConfigOrBool holds information needed to render a FIFO SQS Queue in a container definition.
+type FIFOQueueConfig struct {
+	FIFOThroughputLimit       *string
+	ContentBasedDeduplication *bool
+	DeduplicationScope        *string
 }
 
 // DeadLetterQueue holds information needed to render a dead-letter SQS Queue in a container definition.
@@ -514,10 +550,13 @@ type WorkloadOpts struct {
 	ALBEnabled               bool
 	HostedZoneAliases        AliasesForHostedZone
 	CredentialsParameter     string
+	PermissionsBoundary      string
+	HTTPRedirect             bool
 
 	// Additional options for service templates.
 	WorkloadType            string
 	HealthCheck             *ContainerHealthCheck
+	HTTPTargetContainer     HTTPTargetContainer
 	HTTPHealthCheck         HTTPHealthCheckOpts
 	DeregistrationDelay     *int64
 	AllowedSourceIps        []string
