@@ -17,11 +17,16 @@ import (
 	"golang.org/x/sync/errgroup"
 )
 
-// StackSubscriber is the interface to subscribe channels to a CloudFormation stack stream event.
+// StackSubscriber is the interface to subscribe to a CloudFormation stack event stream.
 type StackSubscriber interface {
 	Subscribe() <-chan stream.StackEvent
 }
 
+// StackSetSubscriber is the interface to subscribe channels to a CloudFormation stack set event stream.
+type StackSetSubscriber interface {
+	Subscribe() <-chan stream.StackSetOpEvent
+}
+
 // ResourceRendererOpts is optional configuration for a listening CloudFormation resource renderer.
 type ResourceRendererOpts struct {
 	StartEvent *stream.StackEvent // Specify the starting event for the resource instead of "[not started]".
@@ -52,6 +57,21 @@ func ListeningStackRenderer(streamer StackSubscriber, stackName, description str
 	return listeningStackComponent(streamer, stackName, description, resourceDescriptions, opts)
 }
 
+// ListeningStackSetRenderer renders a component that listens for CloudFormation stack set events until the streamer stops.
+func ListeningStackSetRenderer(streamer StackSetSubscriber, title string, opts RenderOptions) DynamicRenderer {
+	comp := &stackSetComponent{
+		stream:    streamer.Subscribe(),
+		done:      make(chan struct{}),
+		style:     opts,
+		title:     title,
+		separator: '\t',
+		statuses:  []cfnStatus{notStartedStackStatus},
+		stopWatch: newStopWatch(),
+	}
+	go comp.Listen()
+	return comp
+}
+
 // ListeningResourceRenderer returns a tab-separated component that listens for
 // CloudFormation stack events for a particular resource.
 func ListeningResourceRenderer(streamer StackSubscriber, logicalID, description string, opts ResourceRendererOpts) DynamicRenderer {
@@ -89,10 +109,10 @@ func ListeningECSServiceResourceRenderer(streamer StackSubscriber, ecsDescriber
 
 // regularResourceComponent can display a simple CloudFormation stack resource event.
 type regularResourceComponent struct {
-	logicalID   string        // The LogicalID defined in the template for the resource.
-	description string        // The human friendly explanation of the resource.
-	statuses    []stackStatus // In-order history of the CloudFormation status of the resource throughout the deployment.
-	stopWatch   *stopWatch    // Timer to measure how long the operation takes to complete.
+	logicalID   string      // The LogicalID defined in the template for the resource.
+	description string      // The human friendly explanation of the resource.
+	statuses    []cfnStatus // In-order history of the CloudFormation status of the resource throughout the deployment.
+	stopWatch   *stopWatch  // Timer to measure how long the operation takes to complete.
 
 	padding   int  // Leading spaces before rendering the resource.
 	separator rune // Character used to separate columns of text.
@@ -106,15 +126,18 @@ func listeningResourceComponent(streamer StackSubscriber, logicalID, description
 	comp := &regularResourceComponent{
 		logicalID:   logicalID,
 		description: description,
-		statuses:    []stackStatus{notStartedStackStatus},
+		statuses:    []cfnStatus{notStartedStackStatus},
 		stopWatch:   newStopWatch(),
 		stream:      streamer.Subscribe(),
 		done:        make(chan struct{}),
 		padding:     opts.RenderOpts.Padding,
 		separator:   '\t',
 	}
-	if opts.StartEvent != nil {
-		updateComponentStatus(&comp.mu, &comp.statuses, *opts.StartEvent)
+	if startEvent := opts.StartEvent; startEvent != nil {
+		updateComponentStatus(&comp.mu, &comp.statuses, cfnStatus{
+			value:  cloudformation.StackStatus(startEvent.ResourceStatus),
+			reason: startEvent.ResourceStatusReason,
+		})
 		updateComponentTimer(&comp.mu, comp.statuses, comp.stopWatch)
 	}
 	go comp.Listen()
@@ -127,7 +150,10 @@ func (c *regularResourceComponent) Listen() {
 		if c.logicalID != ev.LogicalResourceID {
 			continue
 		}
-		updateComponentStatus(&c.mu, &c.statuses, ev)
+		updateComponentStatus(&c.mu, &c.statuses, cfnStatus{
+			value:  cloudformation.StackStatus(ev.ResourceStatus),
+			reason: ev.ResourceStatusReason,
+		})
 		updateComponentTimer(&c.mu, c.statuses, c.stopWatch)
 	}
 	close(c.done) // No more events will be processed.
@@ -138,7 +164,7 @@ func (c *regularResourceComponent) Render(out io.Writer) (numLines int, err erro
 	c.mu.Lock()
 	defer c.mu.Unlock()
 
-	components := stackResourceComponents(c.description, c.separator, c.statuses, c.stopWatch, c.padding)
+	components := cfnLineItemComponents(c.description, c.separator, c.statuses, c.stopWatch, c.padding)
 	return renderComponents(out, components)
 }
 
@@ -239,6 +265,46 @@ func (c *stackComponent) addResourceRenderer(ev stream.StackEvent, description s
 	c.resources = append(c.resources, ListeningResourceRenderer(c.stack, ev.LogicalResourceID, description, opts))
 }
 
+// stackSetComponent is a DynamicRenderer that can display stack set operation events.
+type stackSetComponent struct {
+	stream <-chan stream.StackSetOpEvent
+	done   chan struct{}
+
+	style     RenderOptions
+	title     string
+	separator rune
+
+	mu        sync.Mutex
+	statuses  []cfnStatus
+	stopWatch *stopWatch
+}
+
+// Listen consumes stack set operation events and updates the status until the streamer closes the channel.
+func (c *stackSetComponent) Listen() {
+	for ev := range c.stream {
+		updateComponentStatus(&c.mu, &c.statuses, cfnStatus{
+			value:  ev.Operation.Status,
+			reason: ev.Operation.Reason,
+		})
+		updateComponentTimer(&c.mu, c.statuses, c.stopWatch)
+	}
+	close(c.done)
+}
+
+// Render renders the stack set status updates to out and returns the total number of lines written and error if any.
+func (c *stackSetComponent) Render(out io.Writer) (int, error) {
+	c.mu.Lock()
+	defer c.mu.Unlock()
+
+	components := cfnLineItemComponents(c.title, c.separator, c.statuses, c.stopWatch, c.style.Padding)
+	return renderComponents(out, components)
+}
+
+// Done returns a channel that's closed when there are no more events to Listen.
+func (c *stackSetComponent) Done() <-chan struct{} {
+	return c.done
+}
+
 // ecsServiceResourceComponent can display an ECS service created with CloudFormation.
 type ecsServiceResourceComponent struct {
 	// Required inputs.
@@ -340,17 +406,14 @@ func (c *ecsServiceResourceComponent) newListeningRollingUpdateRenderer(serviceA
 	return renderer
 }
 
-func updateComponentStatus(mu *sync.Mutex, statuses *[]stackStatus, event stream.StackEvent) {
+func updateComponentStatus(mu *sync.Mutex, statuses *[]cfnStatus, newStatus cfnStatus) {
 	mu.Lock()
 	defer mu.Unlock()
 
-	*statuses = append(*statuses, stackStatus{
-		value:  cloudformation.StackStatus(event.ResourceStatus),
-		reason: event.ResourceStatusReason,
-	})
+	*statuses = append(*statuses, newStatus)
 }
 
-func updateComponentTimer(mu *sync.Mutex, statuses []stackStatus, sw *stopWatch) {
+func updateComponentTimer(mu *sync.Mutex, statuses []cfnStatus, sw *stopWatch) {
 	mu.Lock()
 	defer mu.Unlock()
 
@@ -375,7 +438,7 @@ func updateComponentTimer(mu *sync.Mutex, statuses []stackStatus, sw *stopWatch)
 	}
 }
 
-func stackResourceComponents(description string, separator rune, statuses []stackStatus, sw *stopWatch, padding int) []Renderer {
+func cfnLineItemComponents(description string, separator rune, statuses []cfnStatus, sw *stopWatch, padding int) []Renderer {
 	columns := []string{fmt.Sprintf("- %s", description), prettifyLatestStackStatus(statuses), prettifyElapsedTime(sw)}
 	components := []Renderer{
 		&singleLineComponent{
